/**
 * The contents of this file are subject to the BT "ZEUS" Open Source 
 * Licence (L77741), Version 1.0 (the "Licence"); you may not use this file 
 * except in compliance with the Licence. You may obtain a copy of the Licence
 * from $ZEUS_INSTALL/licence.html or alternatively from
 * http://www.labs.bt.com/projects/agents/zeus/licence.htm
 * 
 * Except as stated in Clause 7 of the Licence, software distributed under the
 * Licence is distributed WITHOUT WARRANTY OF ANY KIND, either express or 
 * implied. See the Licence for the specific language governing rights and 
 * limitations under the Licence.
 * 
 * The Original Code is within the package zeus.*.
 * The Initial Developer of the Original Code is British Telecommunications
 * public limited company, whose registered office is at 81 Newgate Street, 
 * London, EC1A 7AJ, England. Portions created by British Telecommunications 
 * public limited company are Copyright 1996-9. All Rights Reserved.
 * 
 * THIS NOTICE MUST BE INCLUDED ON ANY COPY OF THIS FILE
 */

package zeus.util;

import java.util.Enumeration;

/**
 * 
 * Tree.java<br>
 * This class under GPL v1, has been modified and commented by <a
 * href="mailto:sebastien.bianco@inria.fr">sebastien bianco</a> - <a
 * href="http://www-rocq.inria.fr/arles">Arles Project - INRIA</a> to be
 * compliant with Java 1.5.<br>
 * <br>
 * 
 * This class offer some method to assert the property of an parameter/value
 * 
 * Modification Date : Jul 18, 2007 4:42:58 PM
 */
public class Tree<T> {

	/** The root node of a tree */
	protected TreeNode<T> root = null;

	/**
	 * Construct a tree object with the data associated to the root
	 * 
	 * @param data
	 *            the object assoated with the root of the tree
	 */
	public Tree(T data) {
		root = new TreeNode<T>(data);
	}

	/**
	 * Construct a tree from a node<br>
	 * #Added by Sebastien Bianco#<br>
	 * 
	 * @param node
	 *            the node to use as root of the tree
	 */
	public Tree(TreeNode<T> node) {
		root = node;
	}

	/**
	 * Get the root of the tree
	 * 
	 * @return the node which is the root of the tree
	 */
	public TreeNode<T> getRoot() {
		return root;
	}

	/**
	 * Get a Enumeration of the values contains in the tree
	 * 
	 * @return a Enumeration of the values contains in the tree
	 */
	public Enumeration<T> values() {
		return root.values();
	}

	/**
	 * Get a Enumeration of the nodes that build the tree
	 * 
	 * @return a Enumeration of the nodes that build the tree
	 */
	public Enumeration<TreeNode<T>> nodes() {
		return root.nodes();
	}

	/**
	 * This method permit to obtain a String description of an under-tree <br>
	 * #Added by Sebastien Bianco#<br>
	 * 
	 * @return the String corresponding to the description of the under-tree
	 */
	public String recursiveToString() {
		return root.recursiveToString("");
	}

	/**
	 * Get the size of the tree<br>
	 * #Added by Sebastien Bianco#<br>
	 * 
	 * @return the size of the tree
	 */
	public int size() {
		return root.size();
	}

	/**
	 * Test if a value is contained in the tree
	 * 
	 * @param data
	 *            we want to locate
	 * @return <i>true</i> if the value is found,<i>false</i> otherwise
	 */
	public boolean containsValue(T data) {
		return root.containsValue(data);
	}

	@SuppressWarnings("unchecked")
	public static void main(String[] args) {
		Tree tree = new Tree("ZeusFact");

		@SuppressWarnings("unused")
		TreeNode root, node;

		root = tree.getRoot();

		TreeNode ZeusFact = tree.getRoot();
		TreeNode Animal = ZeusFact.addChild("Animal");
		TreeNode Fish = Animal.addChild("Fish");
		@SuppressWarnings("unused")
		TreeNode Shark = Fish.addChild("Shark");
		@SuppressWarnings("unused")
		TreeNode Cod = Fish.addChild("Cod");
		TreeNode Mammal = Animal.addChild("Mammal");
		@SuppressWarnings("unused")
		TreeNode Human = Mammal.addChild("Human");
		@SuppressWarnings("unused")
		TreeNode Cat = Mammal.addChild("Cat");
		@SuppressWarnings("unused")
		TreeNode Dog = Mammal.addChild("Dog");
		TreeNode Amphibian = Animal.addChild("Amphibian");
		@SuppressWarnings("unused")
		TreeNode Frog = Amphibian.addChild("Frog");
		@SuppressWarnings("unused")
		TreeNode Toad = Amphibian.addChild("Toad");

		TreeNode TransportDevice = ZeusFact.addChild("TransportDevice");
		@SuppressWarnings("unused")
		TreeNode Car = TransportDevice.addChild("Car");
		@SuppressWarnings("unused")
		TreeNode Bus = TransportDevice.addChild("Bus");

		Enumeration enum1 = tree.nodes();
		while (enum1.hasMoreElements()) {
			node = (TreeNode) enum1.nextElement();
			System.out.println(node);
		}

		System.out.println(tree.recursiveToString());
		System.out.println("size = " + tree.size());

	}
}
