/**
 ##############################################################################
 # Copyright (C) 2006-2010 INRIA
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
 # version 2 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##############################################################################
 * 
 */
package fr.inria.icocoa.junittest.servicemodel.parsers.tools;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

import fr.inria.icocoa.servicemodel.Capability;
import fr.inria.icocoa.servicemodel.parsers.jenaparser.tools.CapabilityForest;

/**
 * CapabilityForestTest.java
 * 
 * @author <a href="mailto:sebastien.bianco@inria.fr">sebastien bianco</a> - <a
 *         href="http://www-rocq.inria.fr/arles">Arles Project - INRIA</a>
 * 
 * Creation Date : Jul 19, 2007 1:24:48 PM
 */
public class CapabilityForestTest {

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.servicemodel.parsers.jenaparser.tools.CapabilityForest#addSubCapability(fr.inria.icocoa.servicemodel.Capability, fr.inria.icocoa.servicemodel.Capability)}.
	 */
	@Test
	public final void testAddSubCapability() {
		CapabilityForest cf = new CapabilityForest();

		/* test add first element */
		Capability a = new Capability("toto#tata", "root");
		cf.addSubCapability(null, a);
		assertTrue("CapabilityForest.forest.size ==1",
				cf.getForest().size() == 1);
		assertTrue("CapabilityForest.capabilitynode.size ==1", cf
				.getCapabilitiesNode().size() == 1);
		assertTrue("tree 0 size = 1", cf.getForest().get(0).size() == 1);

		/* test add null */
		assertNull("test add null-null", cf.addSubCapability(null, null));
		assertTrue("test add null-null -> CapabilityForest.forest.size ==1", cf
				.getForest().size() == 1);
		assertTrue(
				"test add null-null -> CapabilityForest.capabilitynode.size ==1",
				cf.getCapabilitiesNode().size() == 1);
		assertTrue("test add null-null -> tree 0 size = 1", cf.getForest().get(
				0).size() == 1);

		Capability b = new Capability("toto2#tata2", "root2");
		assertNull("test add Capa-null", cf.addSubCapability(b, null));
		assertTrue("test add Capa-null -> CapabilityForest.forest.size ==1", cf
				.getForest().size() == 1);
		assertTrue(
				"test add Capa-null -> CapabilityForest.capabilitynode.size ==1",
				cf.getCapabilitiesNode().size() == 1);
		assertTrue("test add Capa-null -> tree 0 size = 1", cf.getForest().get(
				0).size() == 1);

		/* test add a second element, that is not a root */
		Capability c = new Capability("toto3#tata3", "node");
		Capability d = new Capability("toto4#tata4", "root3");
		cf.addSubCapability(d, c);
		assertTrue("test add d-c -> CapabilityForest.forest.size ==1", cf
				.getForest().size() == 1);
		assertTrue("test add d-c -> CapabilityForest.capabilitynode.size ==3",
				cf.getCapabilitiesNode().size() == 3);
		assertNotNull(
				"test add d-c -> CapabilityForest.capabilitynode.contains(a)",
				cf.getCapabilitiesNode().get(a.getLocalName()));
		assertNotNull(
				"test add d-c -> CapabilityForest.capabilitynode.contains(c)",
				cf.getCapabilitiesNode().get(c.getLocalName()));
		assertNotNull(
				"test add d-c -> CapabilityForest.capabilitynode.contains(d)",
				cf.getCapabilitiesNode().get(d.getLocalName()));
		assertTrue("test add d-c -> tree 0 size = 1", cf.getForest().get(0)
				.size() == 1);

		/* test add a third element that is a child to a previous root */
		Capability e = new Capability("toto5#tata5", "node2");
		cf.addSubCapability(a, e);
		assertTrue("test add a-e -> CapabilityForest.forest.size ==1", cf
				.getForest().size() == 1);
		assertTrue("test add a-e -> CapabilityForest.capabilitynode.size ==4",
				cf.getCapabilitiesNode().size() == 4);
		assertNotNull(
				"test add a-e -> CapabilityForest.capabilitynode.contains(a)",
				cf.getCapabilitiesNode().get(a.getLocalName()));
		assertNotNull(
				"test add a-e -> CapabilityForest.capabilitynode.contains(c)",
				cf.getCapabilitiesNode().get(c.getLocalName()));
		assertNotNull(
				"test add a-e -> CapabilityForest.capabilitynode.contains(d)",
				cf.getCapabilitiesNode().get(d.getLocalName()));
		assertNotNull(
				"test add a-e -> CapabilityForest.capabilitynode.contains(e)",
				cf.getCapabilitiesNode().get(e.getLocalName()));
		assertTrue("test add d-c -> tree 0 size = 2", cf.getForest().get(0)
				.size() == 2);

		/* put d as a root of a new tree */
		cf.addSubCapability(null, d);
		assertTrue("test add d-null -> CapabilityForest.forest.size ==2", cf
				.getForest().size() == 2);
		assertTrue(
				"test add d-null -> CapabilityForest.capabilitynode.size ==4",
				cf.getCapabilitiesNode().size() == 4);
		assertNotNull(
				"test add d-null -> CapabilityForest.capabilitynode.contains(a)",
				cf.getCapabilitiesNode().get(a.getLocalName()));
		assertNotNull(
				"test add d-null -> CapabilityForest.capabilitynode.contains(c)",
				cf.getCapabilitiesNode().get(c.getLocalName()));
		assertNotNull(
				"test add d-null -> CapabilityForest.capabilitynode.contains(d)",
				cf.getCapabilitiesNode().get(d.getLocalName()));
		assertNotNull(
				"test add d-null -> CapabilityForest.capabilitynode.contains(e)",
				cf.getCapabilitiesNode().get(e.getLocalName()));
		assertTrue("test add d-null -> tree 0 size = 2", cf.getForest().get(0)
				.size() == 2);
		assertTrue("test add d-null -> tree 1 size = 2", cf.getForest().get(1)
				.size() == 2);

		Capability f = new Capability("toto8#tata8", "node5");
		cf.addSubCapability(d, new Capability("toto6#tata6", "node3"));
		cf.addSubCapability(e, new Capability("toto7#tata7", "node4"));
		cf.addSubCapability(e, f);
		cf.addSubCapability(c, new Capability("toto9#tata9", "node6"));
		cf.addSubCapability(c, new Capability("toto10#tata10", "node7"));
		cf.addSubCapability(f, new Capability("toto11#tata11", "node8"));
		cf.addSubCapability(f, new Capability("toto12#tata12", "node9"));

		// DebugPrinter.print("forest = \n"+cf.displayForest(), 1);

	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.servicemodel.parsers.jenaparser.tools.CapabilityForest#clear()}.
	 */
	@Test
	public final void testClear() {
		CapabilityForest cf = new CapabilityForest();

		/* add elements */
		Capability a = new Capability("toto#tata", "root");
		cf.addSubCapability(null, a);
		Capability c = new Capability("toto3#tata3", "node");
		Capability d = new Capability("toto4#tata4", "root3");
		cf.addSubCapability(d, c);
		Capability e = new Capability("toto5#tata5", "node2");
		cf.addSubCapability(a, e);
		cf.addSubCapability(null, d);

		assertTrue("before clear -> CapabilityForest.capabilitynode.size ==4",
				cf.getCapabilitiesNode().size() == 4);
		assertTrue("before clear -> CapabilityForest.forest.size ==2", cf
				.getForest().size() == 2);
		assertTrue("before clear -> tree 0 size = 2", cf.getForest().get(0)
				.size() == 2);
		assertTrue("before clear -> tree 1 size = 2", cf.getForest().get(1)
				.size() == 2);

		/* clear the data and test the result */
		cf.clear();
		assertTrue("after clear -> CapabilityForest.forest.size ==0", cf
				.getForest().size() == 0);
		assertTrue("after clear -> CapabilityForest.capabilitynode.size ==0",
				cf.getCapabilitiesNode().size() == 0);

	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.servicemodel.parsers.jenaparser.tools.CapabilityForest#addCapability(fr.inria.icocoa.servicemodel.Capability)}.
	 */
	@Test
	public final void testAddCapability() {

		/** construct Capability Forest by adding node after node */
		CapabilityForest cf = new CapabilityForest();

		Capability a = new Capability("toto#tata", "a");
		Capability b = new Capability("toto2#tata2", "b");
		Capability c = new Capability("toto3#tata3", "c");
		Capability d = new Capability("toto4#tata4", "d");
		Capability e = new Capability("toto5#tata5", "e");
		Capability f = new Capability("toto8#tata8", "f");

		cf.addSubCapability(null, a);
		cf.addSubCapability(a, b);
		cf.addSubCapability(a, e);
		cf.addSubCapability(e, f);
		cf.addSubCapability(e, c);
		cf.addSubCapability(b, d);

		cf.addSubCapability(null, e);

		/** Construct (equivalent) Forest by adding a composite Capability */

		Capability a2 = new Capability("toto#tata", "a");
		Capability b2 = new Capability("toto2#tata2", "b");
		Capability c2 = new Capability("toto3#tata3", "c");
		Capability d2 = new Capability("toto4#tata4", "d");
		Capability e2 = new Capability("toto5#tata5", "e");
		Capability f2 = new Capability("toto8#tata8", "f");

		a2.addSubCapability(b2);
		a2.addSubCapability(e2);
		e2.addSubCapability(f2);
		e2.addSubCapability(c2);
		b2.addSubCapability(d2);

		CapabilityForest cf2 = new CapabilityForest();

		cf2.addCapability(a2);
		cf2.addCapability(e2);

		// DebugPrinter.print("cf = "+cf, 1);
		// DebugPrinter.print("cf2 = "+cf2, 1);

		/** test equivalence */
		assertEquals("test equivalence of String representation",
				cf.toString(), cf2.toString());

	}

}
