/**
 ##############################################################################
 # Copyright (C) 2006-2010 INRIA
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
 # version 2 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##############################################################################
 * 
 */
package fr.inria.icocoa.junittest.servicemodel.semantictype;

import static org.junit.Assert.assertTrue;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import fr.inria.icocoa.common.DebugPrinter;
import fr.inria.icocoa.common.Tools;
import fr.inria.icocoa.servicemodel.Input;
import fr.inria.icocoa.servicemodel.Service;
import fr.inria.icocoa.servicemodel.parsers.ServiceParserFactory;
import fr.inria.icocoa.servicemodel.semantictype.Code;
import fr.inria.icocoa.servicemodel.semantictype.EncodedSemanticType;
import fr.inria.icocoa.servicemodel.semantictype.encryptionmanagement.BigIntegerCode;
import fr.inria.icocoa.servicemodel.semantictype.encryptionmanagement.EncodedOntologiesManager;
import fr.inria.icocoa.servicemodel.semantictype.encryptionmanagement.Encoder;

/**
 * PrimeNumberEncodedSemanticTypeTest.java
 *
 * @author <a href="mailto:sebastien.bianco@inria.fr">sebastien bianco</a> - <a href="http://www-rocq.inria.fr/arles">Arles Project - INRIA</a>
 * 
 * Creation Date : Apr 7, 2008 3:22:42 PM
 */
public class PrimeNumberEncodedSemanticTypeTest {
	
	private Service service = null;
	
	/**
	 * Done before launching tests => Load the Ontology
	 * @throws Exception
	 */
	@Before
	public void setUpBeforeClass() throws Exception {
		/*
		 * Parse a service so as to set a value to JenaParser.getHashCodeValue
		 * So the associated encoded ontologies will be used when different object will be created during test.
		 */
		String SDLfilename = System.getProperty("user.dir")
		+ "/amigo-s/SebEchoService.owl";
		String serviceFile = Tools.readFromFile(SDLfilename);
		
		this.service = ServiceParserFactory.getInstance().getParser().parseProcessFromString(serviceFile,false);
	
			
	}

	@After
	public void tearDown() throws Exception {
	}


	/**
	 * Test method for {@link fr.inria.icocoa.servicemodel.semantictype.PrimeNumberEncodedSemanticType#isEquals(fr.inria.icocoa.servicemodel.semantictype.EncodedSemanticType)}.
	 */
	@Test
	public final void testIsEquals() {
		Input in1 = new Input("semIn1","http://www.inria.fr/myPiOntology2.owl#SemIn1");
		Input in2 = new Input("semIn11","http://www.inria.fr/myPiOntology2.owl#SemIn11");
		EncodedSemanticType sem1 = (EncodedSemanticType)in1.getSemanticType();
		EncodedSemanticType sem2 = (EncodedSemanticType)in2.getSemanticType();	
		
	///	DebugPrinter.print("sem1 = "+sem1+" , sem2 = "+sem2,DebugPrinter.INFO);
		
		assertTrue("in1 == in2",sem1.isEquals(sem2));
		
	}

	/**
	 * Test method for {@link fr.inria.icocoa.servicemodel.semantictype.PrimeNumberEncodedSemanticType#isSubsum(fr.inria.icocoa.servicemodel.semantictype.EncodedSemanticType)}.
	 */
	@Test
	public final void testIsSubsum() {
		
		Input in1 = new Input("semIn1","http://www.inria.fr/myPiOntology2.owl#SemIn1");
		Input in2 = new Input("semInChild1","http://www.inria.fr/myPiOntology2.owl#SemInChild1");
		EncodedSemanticType sem1 = (EncodedSemanticType)in1.getSemanticType();
		EncodedSemanticType sem2 = (EncodedSemanticType)in2.getSemanticType();	
		
	///	DebugPrinter.print("sem1 = "+sem1+" , sem2 = "+sem2,DebugPrinter.INFO);
		
		assertTrue("in1 > in2",sem2.isSubsum(sem1));
		
	}

	/**
	 * Test method for {@link fr.inria.icocoa.servicemodel.semantictype.PrimeNumberEncodedSemanticType#isPlugin(fr.inria.icocoa.servicemodel.semantictype.EncodedSemanticType)}.
	 */
	@Test
	public final void testIsPlugin() {
		Input in1 = new Input("semIn1","http://www.inria.fr/myPiOntology2.owl#SemIn1");
		Input in2 = new Input("semInChild1","http://www.inria.fr/myPiOntology2.owl#SemInChild1");
		EncodedSemanticType sem1 = (EncodedSemanticType)in1.getSemanticType();
		EncodedSemanticType sem2 = (EncodedSemanticType)in2.getSemanticType();	
		
	///	DebugPrinter.print("sem1 = "+sem1+" , sem2 = "+sem2,DebugPrinter.INFO);
		
		assertTrue("in2 < in1",sem1.isPlugin(sem2));
		
	}

	

	/**
	 * Test method for {@link fr.inria.icocoa.servicemodel.semantictype.PrimeNumberEncodedSemanticType#encode(java.util.List)}.
	 * @throws IllegalAccessException 
	 * @throws InstantiationException 
	 */
	@Test
	public final void testEncode() throws InstantiationException, IllegalAccessException {
		
//		create list of ontologies to load
		List<String> ontologyToLoad = new ArrayList<String>();
		ontologyToLoad.add("http://www.inria.fr/myPiOntology.owl");
	
		EncodedSemanticType semType = EncodedOntologiesManager.getInstance().getEncryptionClass().newInstance();
		//DebugPrinter.print("semType = "+semType,DebugPrinter.INFO);
		Encoder encoder = semType.getAssociatedEncoder().newInstance();
		//DebugPrinter.print("encoder = "+encoder,DebugPrinter.INFO);
		
		Map<String, List<Code>> result = encoder.encode(ontologyToLoad);
		
		//DebugPrinter.print(result,"result", DebugPrinter.INFO);
		//DebugPrinter.print("size = "+result.size(),DebugPrinter.INFO);
		
				
		assertTrue("http://www.w3.org/2002/07/owl#Thing",((BigIntegerCode)result.get("http://www.w3.org/2002/07/owl#Thing").get(0)).getValue().equals(new BigInteger("2")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemIn2",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemIn2").get(0)).getValue().equals(new BigInteger("1726")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOutChild1",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOutChild1").get(0)).getValue().equals(new BigInteger("596642")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild1",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild1").get(0)).getValue().equals(new BigInteger("42685306")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#PI2",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#PI2").get(0)).getValue().equals(new BigInteger("778")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemIn4",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemIn4").get(0)).getValue().equals(new BigInteger("2326")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapa3",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa3").get(0)).getValue().equals(new BigInteger("554")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemIn11",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemIn11").get(0)).getValue().equals(new BigInteger("146")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemInChildChild2",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemInChildChild2").get(0)).getValue().equals(new BigInteger("1438677958")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOut11",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOut11").get(0)).getValue().equals(new BigInteger("2218")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapa11",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa11").get(0)).getValue().equals(new BigInteger("1154")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemInChildChildChild1",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemInChildChildChild1").get(0)).getValue().equals(new BigInteger("1009075058")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemInChild2",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemInChild2").get(0)).getValue().equals(new BigInteger("1565482")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOutChild2",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOutChild2").get(0)).getValue().equals(new BigInteger("34306")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOutChild11",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOutChild11").get(0)).getValue().equals(new BigInteger("596642")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemInChildChild1",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemInChildChild1").get(0)).getValue().equals(new BigInteger("1026526")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOutChild3",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOutChild3").get(0)).getValue().equals(new BigInteger("292342")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOut31",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOut31").get(0)).getValue().equals(new BigInteger("626")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapa21",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa21").get(0)).getValue().equals(new BigInteger("1982")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapa2",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa2").get(0)).getValue().equals(new BigInteger("1982")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOutChildChild3",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOutChildChild3").get(0)).getValue().equals(new BigInteger("82732786")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemIn1",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemIn1").get(0)).getValue().equals(new BigInteger("146")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemInChild1",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemInChild1").get(0)).getValue().equals(new BigInteger("11534")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemIn31",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemIn31").get(0)).getValue().equals(new BigInteger("2062")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapa31",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa31").get(0)).getValue().equals(new BigInteger("554")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOut1",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOut1").get(0)).getValue().equals(new BigInteger("2218")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemInChild31",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemInChild31").get(0)).getValue().equals(new BigInteger("1932094")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapaChild1",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChild1").get(0)).getValue().equals(new BigInteger("908198")));		
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOutChildChild31",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOutChildChild31").get(0)).getValue().equals(new BigInteger("82732786")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemInChild11",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemInChild11").get(0)).getValue().equals(new BigInteger("11534")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild11",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild11").get(0)).getValue().equals(new BigInteger("42685306")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemInChild3",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemInChild3").get(0)).getValue().equals(new BigInteger("1932094")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemInChildChild11",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemInChildChild11").get(0)).getValue().equals(new BigInteger("1026526")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemInChildChild3",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemInChildChild3").get(0)).getValue().equals(new BigInteger("2119507118")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemIn21",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemIn21").get(0)).getValue().equals(new BigInteger("1726")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#PI3",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#PI3").get(0)).getValue().equals(new BigInteger("2038")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOut3",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOut3").get(0)).getValue().equals(new BigInteger("626")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapa1",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa1").get(0)).getValue().equals(new BigInteger("1154")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOutChildChild2",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOutChildChild2").get(0)).getValue().equals(new BigInteger("34751978")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOut4",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOut4").get(0)).getValue().equals(new BigInteger("2206")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapaChildChildChild1",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChildChild1").get(0)).getValue().equals(new BigInteger("35300748062")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOut2",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOut2").get(0)).getValue().equals(new BigInteger("34")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#PI",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#PI").get(0)).getValue().equals(new BigInteger("2038")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemIn3",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemIn3").get(0)).getValue().equals(new BigInteger("2062")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemOut21",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemOut21").get(0)).getValue().equals(new BigInteger("34")));		
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapaChild2",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChild2").get(0)).getValue().equals(new BigInteger("838958")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild21",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild21").get(0)).getValue().equals(new BigInteger("652982560875188")));
		assertTrue("http://www.inria.fr/myPiOntology.owl#SemCapaChildChildChild2",((BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChildChild2").get(0)).getValue().equals(new BigInteger("36666677854")));
	
		
	}

}
