/**
 ##############################################################################
 # Copyright (C) 2006-2010 INRIA
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
 # version 2 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##############################################################################
 * 
 */
package fr.inria.icocoa.junittest.servicemodel.semantictype.encoder;

import static org.junit.Assert.*;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import fr.inria.icocoa.common.DebugPrinter;
import fr.inria.icocoa.servicemodel.semantictype.Code;
import fr.inria.icocoa.servicemodel.semantictype.EncodedSemanticType;
import fr.inria.icocoa.servicemodel.semantictype.encryptionmanagement.BigIntegerCode;
import fr.inria.icocoa.servicemodel.semantictype.encryptionmanagement.EncodedOntologiesManager;
import fr.inria.icocoa.servicemodel.semantictype.encryptionmanagement.Encoder;

/**
 * BigIntegerCodeTest.java
 *
 * @author <a href="mailto:sebastien.bianco@inria.fr">sebastien bianco</a> - <a href="http://www-rocq.inria.fr/arles">Arles Project - INRIA</a>
 * 
 * Creation Date : Apr 11, 2008 4:26:49 PM
 */
public class BigIntegerCodeTest {
private Map<String, List<Code>> result;
	
	/**
	 * Done before launching tests => Load the Ontology
	 * @throws Exception
	 */
	@Before
	public void setUp() throws Exception {
		//create list of ontologies to load
		List<String> ontologyToLoad = new ArrayList<String>();
		ontologyToLoad.add("http://www.inria.fr/myPiOntology.owl");
	
		EncodedSemanticType semType = EncodedOntologiesManager.getInstance().getEncryptionClass().newInstance();
		DebugPrinter.print("semType = "+semType,DebugPrinter.INFO);
		Encoder encoder = semType.getAssociatedEncoder().newInstance();
		DebugPrinter.print("encoder = "+encoder,DebugPrinter.INFO);
		
		this.result = encoder.encode(ontologyToLoad);
		
		DebugPrinter.print(result,"result", DebugPrinter.INFO);
		DebugPrinter.print("size = "+result.size(),DebugPrinter.INFO);
		
	}

	/**
	 * @throws java.lang.Exception
	 */
	@After
	public void tearDown() throws Exception {
	}

	/**
	 * Test method for {@link fr.inria.icocoa.servicemodel.semantictype.encryptionmanagement.BigIntegerCode#isExact(fr.inria.icocoa.servicemodel.semantictype.Code)}.
	 */
	@Test
	public final void testIsExact() {
		BigIntegerCode PI = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#PI").get(0);
		BigIntegerCode PI3 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#PI3").get(0);
		assertTrue("PI vs PI3",PI.isExact(PI3));
		assertTrue("PI3 vs PI",PI3.isExact(PI));
		assertTrue("PI vs PI3",PI.isExact(PI));
		
		BigIntegerCode semCapa1 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa11").get(0);
		BigIntegerCode semCapa11 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa1").get(0);
		assertTrue("semCapa1 vs semCapa11",semCapa1.isExact(semCapa11));
		assertTrue("semCapa11 vs semCapa1",semCapa11.isExact(semCapa1));
		
		BigIntegerCode semCapaChildChild1 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild11").get(0);
		BigIntegerCode semCapaChildChild11 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild1").get(0);
		assertTrue("semCapaChildChild1 vs semCapaChildChild11",semCapaChildChild1.isExact(semCapaChildChild11));
		assertTrue("semCapaChildChild11 vs semCapaChildChild1",semCapaChildChild11.isExact(semCapaChildChild1));
		
		
	}

	/**
	 * Test method for {@link fr.inria.icocoa.servicemodel.semantictype.encryptionmanagement.BigIntegerCode#isPlugin(fr.inria.icocoa.servicemodel.semantictype.Code)}.
	 */
	@Test
	public final void testIsPlugin() {
		BigIntegerCode semCapaChildChildChild1 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChildChild1").get(0);
		BigIntegerCode semCapaChildChild1 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild1").get(0);
		BigIntegerCode semCapaChildChild11 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild11").get(0);
		BigIntegerCode semCapaChild1 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChild1").get(0);
		BigIntegerCode semCapa1 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa1").get(0);
		BigIntegerCode semCapa11 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa11").get(0);
		assertTrue("semCapaChildChild1 vs semCapaChild1",semCapaChild1.isPlugin(semCapaChildChild1));
		assertTrue("semCapaChildChild11 vs semCapaChild1",semCapaChild1.isPlugin(semCapaChildChild11));
		assertTrue("semCapaChildChild11 vs semCapa1",semCapa1.isPlugin(semCapaChildChild11));
		assertTrue("semCapaChildChild11 vs semCapa11",semCapa11.isPlugin(semCapaChildChild11));
		assertTrue("semCapaChildChildChild1 vs semCapaChildChild1",semCapaChildChild1.isPlugin(semCapaChildChildChild1));
		assertTrue("semCapaChildChildChild1 vs semCapaChild1",semCapaChild1.isPlugin(semCapaChildChildChild1));
		assertTrue("semCapaChildChildChild1 vs semCapa1",semCapa1.isPlugin(semCapaChildChildChild1));
	}

	/**
	 * Test method for {@link fr.inria.icocoa.servicemodel.semantictype.encryptionmanagement.BigIntegerCode#isSubsum(fr.inria.icocoa.servicemodel.semantictype.Code)}.
	 */
	@Test
	public final void testIsSubsum() {		
		BigIntegerCode semCapaChildChildChild1 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChildChild1").get(0);
		BigIntegerCode semCapaChildChild1 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild1").get(0);
		BigIntegerCode semCapaChildChild11 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild11").get(0);
		BigIntegerCode semCapaChild1 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapaChild1").get(0);
		BigIntegerCode semCapa1 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa1").get(0);
		BigIntegerCode semCapa11 = (BigIntegerCode)result.get("http://www.inria.fr/myPiOntology.owl#SemCapa11").get(0);
		assertTrue("semCapaChildChild1 vs semCapaChild1",semCapaChildChild1.isSubsum(semCapaChild1));
		assertTrue("semCapaChildChild11 vs semCapaChild1",semCapaChildChild11.isSubsum(semCapaChild1));
		assertTrue("semCapaChildChild11 vs semCapa1",semCapaChildChild11.isSubsum(semCapa1));
		assertTrue("semCapaChildChild11 vs semCapa11",semCapaChildChild11.isSubsum(semCapa11));
		assertTrue("semCapaChildChildChild1 vs semCapaChildChild1",semCapaChildChildChild1.isSubsum(semCapaChildChild1));
		assertTrue("semCapaChildChildChild1 vs semCapaChild1",semCapaChildChildChild1.isSubsum(semCapaChild1));
		assertTrue("semCapaChildChildChild1 vs semCapa1",semCapaChildChildChild1.isSubsum(semCapa1));
	}
}
