/**
 ##############################################################################
 # Copyright (C) 2006-2010 INRIA
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
 # version 2 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##############################################################################
 * 
 */
package fr.inria.icocoa.junittest.servicemodel.semantictype.encoder.jenaencoder;

import static org.junit.Assert.*;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;

import fr.inria.icocoa.servicemodel.semantictype.encoder.jenaencoder.JenaOntologiesGraphGenerator;
import fr.inria.icocoa.servicemodel.semantictype.encryptionmanagement.toolobjects.Node;

/**
 * 
 * JenaOntologiesGraphGeneratorTest.java
 *
 * @author <a href="mailto:sebastien.bianco@inria.fr">sebastien bianco</a> - <a href="http://www-rocq.inria.fr/arles">Arles Project - INRIA</a>
 * 
 * Creation Date : Apr 2, 2008 3:15:22 PM
 */
public class JenaOntologiesGraphGeneratorTest {

	@Test
	public final void testGenerateOntologiesGraph() {
		//create list of ontologies to load
		List<String> ontologyToLoad = new ArrayList<String>();
		ontologyToLoad.add("http://www.inria.fr/myPiOntology.owl");
		
		//generate the graph of node
		JenaOntologiesGraphGenerator graphGenerator = new JenaOntologiesGraphGenerator();
		Node generatedRootNode = graphGenerator.generateOntologiesGraph(ontologyToLoad);
			
		
		//displayTheResult
		//DebugPrinter.print("\n"+generatedRootNode.displayNode(""),DebugPrinter.INFO);
		
		/*
		 *Generate the required result 
		 */
		Node rootNode = new Node("http://www.w3.org/2002/07/owl#Thing");
		//rootNode.addChild(new Node("http://www.w3.org/2002/07/owl#Nothing"));
		
		Node PI = new Node("http://www.inria.fr/myPiOntology.owl#PI");
		rootNode.addChild(PI);
		
		Node PI3 = new Node("http://www.inria.fr/myPiOntology.owl#PI3");
		rootNode.addChild(PI3);		
		PI.addEquivalent(PI3);
		PI3.addEquivalent(PI);
		
		
		rootNode.addChild(new Node("http://www.inria.fr/myPiOntology.owl#PI2"));
		
		
		//construct resulting graph
		Node semCapaChildChildChild1 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapaChildChildChild1");
		rootNode.addChild(semCapaChildChildChild1);
		Node semCapaChildChildChild2 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapaChildChildChild2");
		rootNode.addChild(semCapaChildChildChild2);
		Node semCapaChildChild1 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild1");
		rootNode.addChild(semCapaChildChild1);
		Node semCapaChildChild21 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild21");
		rootNode.addChild(semCapaChildChild21);
		Node semCapaChild1 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapaChild1");
		rootNode.addChild(semCapaChild1);
		Node semCapaChild2 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapaChild2");
		rootNode.addChild(semCapaChild2);
		Node semCapa1 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapa1");
		rootNode.addChild(semCapa1);
		semCapaChildChild1.addChild(semCapaChildChildChild1);
		semCapaChildChild1.addChild(semCapaChildChildChild2);
		
		semCapaChild1.addChild(semCapaChildChild1);
		semCapaChild1.addChild(semCapaChildChild21);
		semCapaChild1.addChild(semCapaChildChildChild2);
	
		semCapaChild2.addChild(semCapaChildChild21);
		
		Node semCapaChildChild11 =  new Node("http://www.inria.fr/myPiOntology.owl#SemCapaChildChild11");
		rootNode.addChild(semCapaChildChild11);
		semCapaChildChild1.addEquivalent(semCapaChildChild11);
		semCapaChildChild11.addEquivalent(semCapaChildChild1);
		

		semCapaChildChild1.addChild(semCapaChildChild11);

		semCapaChild1.addChild(semCapaChildChildChild1);
		semCapaChild1.addChild(semCapaChildChild11);
		semCapaChildChild11.addChild(semCapaChildChildChild1);
		semCapaChildChild11.addChild(semCapaChildChildChild2);
		
		Node semCapa11 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapa11");
		rootNode.addChild(semCapa11);
		semCapa11.addEquivalent(semCapa1);
		semCapa1.addEquivalent(semCapa11);
		
		Node semCapa2 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapa2");
		rootNode.addChild(semCapa2);
		Node semCapa21 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapa21");
		rootNode.addChild(semCapa21);
		semCapa2.addEquivalent(semCapa21);
		semCapa21.addEquivalent(semCapa2);
		
		Node semCapa3 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapa3");
		rootNode.addChild(semCapa3);
		Node semCapa31 = new Node("http://www.inria.fr/myPiOntology.owl#SemCapa31");
		rootNode.addChild(semCapa31);
		semCapa3.addEquivalent(semCapa31);
		semCapa31.addEquivalent(semCapa3);
			
		semCapa1.addChild(semCapaChildChild1);
		semCapa1.addChild(semCapaChildChild11);
		semCapa1.addChild(semCapaChildChildChild1);
		semCapa1.addChild(semCapaChild1);
		semCapa1.addChild(semCapaChild2);
		semCapa1.addChild(semCapaChildChild21);
		semCapa1.addChild(semCapaChildChildChild2);	
				
		semCapa11.addChild(semCapaChild1);
		semCapa11.addChild(semCapaChildChild1);
		semCapa11.addChild(semCapaChildChild11);
		semCapa11.addChild(semCapaChildChildChild1);
		semCapa11.addChild(semCapaChild2);
		semCapa11.addChild(semCapaChildChild21);
		semCapa11.addChild(semCapaChildChildChild2);
		
		
		
		
		Node semInChildChildChild1 = new Node("http://www.inria.fr/myPiOntology.owl#SemInChildChildChild1");
		rootNode.addChild(semInChildChildChild1);
		Node semInChildChild1 = new Node("http://www.inria.fr/myPiOntology.owl#SemInChildChild1");
		rootNode.addChild(semInChildChild1);
		Node semInChild1 = new Node("http://www.inria.fr/myPiOntology.owl#SemInChild1");
		rootNode.addChild(semInChild1);
		Node semIn1 = new Node("http://www.inria.fr/myPiOntology.owl#SemIn1");
		rootNode.addChild(semIn1);
		semInChildChild1.addChild(semInChildChildChild1);
		semInChild1.addChild(semInChildChild1);
		semIn1.addChild(semInChild1);
		
		Node semIn11 = new Node("http://www.inria.fr/myPiOntology.owl#SemIn11");
		rootNode.addChild(semIn11);
		semIn11.addEquivalent(semIn1);
		semIn1.addEquivalent(semIn11);
		
		Node semInChild11 = new Node("http://www.inria.fr/myPiOntology.owl#SemInChild11");
		rootNode.addChild(semInChild11);		
		semInChild11.addEquivalent(semInChild1);
		semInChild1.addEquivalent(semInChild11);	

		rootNode.addChild(new Node("http://www.inria.fr/myPiOntology.owl#SemIn4"));		
		
		Node semInChildChild2 = new Node("http://www.inria.fr/myPiOntology.owl#SemInChildChild2");
		rootNode.addChild(semInChildChild2);
		Node semInChild2 = new Node("http://www.inria.fr/myPiOntology.owl#SemInChild2");
		rootNode.addChild(semInChild2);
		Node semIn2 = new Node("http://www.inria.fr/myPiOntology.owl#SemIn2");
		rootNode.addChild(semIn2);
		semInChild2.addChild(semInChildChild2);
		semIn2.addChild(semInChild2);
			
		Node semIn21 = new Node("http://www.inria.fr/myPiOntology.owl#SemIn21");
		rootNode.addChild(semIn21);
		semIn21.addEquivalent(semIn2);
		semIn2.addEquivalent(semIn21);
			
		Node semInChildChild3 = new Node("http://www.inria.fr/myPiOntology.owl#SemInChildChild3");
		rootNode.addChild(semInChildChild3);
		Node semInChild3 = new Node("http://www.inria.fr/myPiOntology.owl#SemInChild3");
		rootNode.addChild(semInChild3);
		Node semIn3 = new Node("http://www.inria.fr/myPiOntology.owl#SemIn3");
		rootNode.addChild(semIn3);
		semInChild3.addChild(semInChildChild3);
		semIn3.addChild(semInChild3);		
		
		Node semIn31 = new Node("http://www.inria.fr/myPiOntology.owl#SemIn31");
		rootNode.addChild(semIn31);
		semIn31.addEquivalent(semIn3);
		semIn3.addEquivalent(semIn31);			
		
		Node semInChild31 = new Node("http://www.inria.fr/myPiOntology.owl#SemInChild31");
		rootNode.addChild(semInChild31);
		semInChild31.addEquivalent(semInChild3);
		semInChild3.addEquivalent(semInChild31);			
		
		Node semInChildChild11 = new Node("http://www.inria.fr/myPiOntology.owl#SemInChildChild11");
		rootNode.addChild(semInChildChild11);
		semInChildChild11.addEquivalent(semInChildChild1);
		semInChildChild1.addEquivalent(semInChildChild11);
		
		semInChildChild11.addChild(semInChildChildChild1);
		
		semInChild1.addChild(semInChildChild11);
		semInChild1.addChild(semInChildChildChild1);
		
		semIn1.addChild(semInChild11);
		semIn1.addChild(semInChildChild11);
		semIn1.addChild(semInChildChild1);
		semIn1.addChild(semInChildChildChild1);
		
		semIn11.addChild(semInChild11);
		semIn11.addChild(semInChild1);
		semIn11.addChild(semInChildChild11);
		semIn11.addChild(semInChildChild1);
		semIn11.addChild(semInChildChildChild1);
		
		semInChild11.addChild(semInChildChild1);
		semInChild11.addChild(semInChildChildChild1);
		semInChild11.addChild(semInChildChild11);
		
		semIn2.addChild(semInChildChild2);
		
		semIn21.addChild(semInChildChild2);		
		semIn21.addChild(semInChild2);	
		
		semIn3.addChild(semInChild31);
		semIn3.addChild(semInChildChild3);
		
		semIn31.addChild(semInChild31);
		semIn31.addChild(semInChildChild3);
		semIn31.addChild(semInChild3);
		
		semInChild31.addChild(semInChildChild3);
		
		rootNode.addChild(new Node("http://www.inria.fr/myPiOntology.owl#SemIn4"));
		
		
	
		
		Node semOut1 = new Node("http://www.inria.fr/myPiOntology.owl#SemOut1");
		rootNode.addChild(semOut1);		
				
		Node semOutChild11 = new Node("http://www.inria.fr/myPiOntology.owl#SemOutChild11");
		rootNode.addChild(semOutChild11);
		Node semOut11 = new Node("http://www.inria.fr/myPiOntology.owl#SemOut11");
		rootNode.addChild(semOut11);
		semOut11.addEquivalent(semOut1);
		semOut1.addEquivalent(semOut11);		
		semOut11.addChild(semOutChild11);
						
		Node semOutChildChild2 = new Node("http://www.inria.fr/myPiOntology.owl#SemOutChildChild2");
		rootNode.addChild(semOutChildChild2);
		Node semOutChild2 = new Node("http://www.inria.fr/myPiOntology.owl#SemOutChild2");
		rootNode.addChild(semOutChild2);
		Node semOut2 = new Node("http://www.inria.fr/myPiOntology.owl#SemOut2");
		rootNode.addChild(semOut2);
		Node semOut21 = new Node("http://www.inria.fr/myPiOntology.owl#SemOut21");
		rootNode.addChild(semOut21);
		semOut2.addEquivalent(semOut21);
		semOut21.addEquivalent(semOut2);
		semOutChild2.addChild(semOutChildChild2);
		semOut2.addChild(semOutChild2);		
		
		rootNode.addChild(new Node("http://www.inria.fr/myPiOntology.owl#SemOut21"));	
		
		Node semOutChildChild3 = new Node("http://www.inria.fr/myPiOntology.owl#SemOutChildChild3");
		rootNode.addChild(semOutChildChild3);		
		Node semOutChild3 = new Node("http://www.inria.fr/myPiOntology.owl#SemOutChild3");
		rootNode.addChild(semOutChild3);		
		Node semOut3 = new Node("http://www.inria.fr/myPiOntology.owl#SemOut3");
		rootNode.addChild(semOut3);		
		Node semOut31 = new Node("http://www.inria.fr/myPiOntology.owl#SemOut31");
		rootNode.addChild(semOut31);	
		semOut3.addEquivalent(semOut31);
		semOut31.addEquivalent(semOut3);
		semOutChild3.addChild(semOutChildChild3);
		semOut3.addChild(semOutChild3);
		
		rootNode.addChild(new Node("http://www.inria.fr/myPiOntology.owl#SemOut4"));	
		
		Node semOutChild1 = new Node("http://www.inria.fr/myPiOntology.owl#SemOutChild1");
		rootNode.addChild(semOutChild1);	
		semOutChild1.addEquivalent(semOutChild11);
		semOutChild11.addEquivalent(semOutChild1);			
		
		Node semOutChildChild31 = new Node("http://www.inria.fr/myPiOntology.owl#SemOutChildChild31");
		rootNode.addChild(semOutChildChild31);		
		semOutChildChild3.addEquivalent(semOutChildChild31);
		semOutChildChild31.addEquivalent(semOutChildChild3);
		
		semOut1.addChild(semOutChild1);
		semOut1.addChild(semOutChild11);
		
		semOut11.addChild(semOutChild1);
		
		semOut2.addChild(semOutChildChild2);
		
		semOut21.addChild(semOutChild2);
		semOut21.addChild(semOutChildChild2);
		
		semOutChild3.addChild(semOutChildChild31);
		
		semOut31.addChild(semOutChild3);
		semOut31.addChild(semOutChildChild3);
		semOut31.addChild(semOutChildChild31);
		
		semOut3.addChild(semOutChildChild3);
		semOut3.addChild(semOutChildChild31);
		
		
		
		//DebugPrinter.print("RESULT\n"+rootNode.displayNode(""),DebugPrinter.INFO);
		
		//DebugPrinter.print(generatedRootNode.getChildren(),"",DebugPrinter.INFO);
		//DebugPrinter.print(rootNode.getChildren(),"",DebugPrinter.INFO);
		
		assertTrue("test graph",rootNode.deepEquals(generatedRootNode));
	}

}
