/**
 ##############################################################################
 # Copyright (C) 2006-2010 INRIA
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
 # version 2 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##############################################################################
 * 
 */

package fr.inria.icocoa.junittest.common;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

import org.junit.Test;

import fr.inria.icocoa.common.Tools;
import fr.inria.icocoa.servicemodel.IO;

/**
 * ToolsTest.java<br>
 * 
 * This class contains tests for the class {@link fr.inria.icocoa.common.Tools}
 * 
 * @author <a href="mailto:sebastien.bianco@inria.fr">sebastien bianco</a> - <a
 *         href="http://www-rocq.inria.fr/arles">Arles Project - INRIA</a>
 * 
 * Creation Date : Apr 17, 2007
 */
public class ToolsTest {

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.common.Tools#compareString(java.lang.String, java.lang.String)}.
	 */
	@Test
	public final void testCompareString() {
		String s1 = "toto";
		String s2 = "toto";
		String s3 = null;
		String s4 = null;
		String s5 = "toto2";

		assertTrue("same content", Tools.compareString(s1, s2));
		assertTrue("same content 2", Tools.compareString(s2, s1));
		assertTrue("same content but null", Tools.compareString(s3, s4));
		assertTrue("same content but null 2", Tools.compareString(s4, s3));
		assertFalse("not same content", Tools.compareString(s1, s5));
		assertFalse("not same content 2", Tools.compareString(s5, s1));
		assertFalse("not same content but null", Tools.compareString(s1, s3));
		assertFalse("not same content but null 2", Tools.compareString(s3, s1));
	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.common.Tools#compareList(java.util.List, java.util.List)}.
	 */
	@Test
	public final void testCompareList() {
		List<String> master = new ArrayList<String>();
		master.add("toto");
		master.add("titi");
		master.add("tata");
		List<String> master2 = new ArrayList<String>();
		master2.add("toto");
		master2.add("titi");
		master2.add("tata2");
		List<String> master3 = new ArrayList<String>();
		master3.add("toto");
		master3.add("titi");
		master3.add("tata");
		master3.add("tutu");

		List<String> l1 = new ArrayList<String>();
		List<String> l2 = new LinkedList<String>();
		List<String> l3 = new ArrayList<String>();
		List<String> l9 = new LinkedList<String>();
		l1.addAll(master);
		l2.addAll(master);
		l3.addAll(master2);
		l9.addAll(master3);

		assertTrue("same content", Tools.compareList(l1, l2));
		assertTrue("same content 2", Tools.compareList(l2, l1));
		assertFalse("not same content", Tools.compareList(l1, l3));
		assertFalse("not same content 2", Tools.compareList(l3, l1));
		assertFalse("not same content (not same size)", Tools.compareList(l1,
				l9));
		assertFalse("not same content (not same size) 2", Tools.compareList(l9,
				l1));

		List<String> l4 = new ArrayList<String>();
		List<String> l5 = new ArrayList<String>();

		assertTrue("same content but empty", Tools.compareList(l4, l5));
		assertTrue("same content but empty 2", Tools.compareList(l5, l4));

		List<String> l6 = null;
		List<String> l7 = null;

		assertTrue("same content but null", Tools.compareList(l6, l7));
		assertTrue("same content but null 2", Tools.compareList(l7, l6));

		assertFalse("not same content (one null)", Tools.compareList(l6, l1));
		assertFalse("not same content (one null) 2", Tools.compareList(l1, l6));
		assertFalse("not same content (one empty)", Tools.compareList(l4, l1));
		assertFalse("not same content (one empty) 2", Tools.compareList(l1, l4));

		l9.remove("tutu");
		assertTrue("same content (after change)", Tools.compareList(l1, l9));

		List<Integer> l10 = new LinkedList<Integer>();
		l10.add(new Integer(10));
		assertFalse("not sameContent (not same type)", Tools.compareList(l1,
				l10));
		assertFalse("not sameContent (not same type) 2", Tools.compareList(l10,
				l1));

	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.common.Tools#compareMap(java.util.Map, java.util.Map)}.
	 */
	@Test
	public final void testCompareMap() {
		Map<String, String> master = new HashMap<String, String>();
		master.put("key1", "toto");
		master.put("key2", "tata");
		master.put("key3", "titi");

		Map<String, String> master_unordered = new HashMap<String, String>();
		master_unordered.put("key2", "toto");
		master_unordered.put("key1", "tata");
		master_unordered.put("key3", "titi");

		Map<String, String> master_unordered_2 = new HashMap<String, String>();
		master_unordered_2.put("key1", "titi");
		master_unordered_2.put("key2", "tata");
		master_unordered_2.put("key3", "toto");

		Map<String, String> master2 = new HashMap<String, String>();
		master2.put("key1", "toto");
		master2.put("key2", "tata2");
		master2.put("key3", "titi");

		Map<String, String> master3 = new HashMap<String, String>();
		master3.put("key1", "toto");
		master3.put("key23", "tata");
		master3.put("key3", "titi");

		Map<String, String> master4 = new HashMap<String, String>();
		master4.put("key1", "toto");
		master4.put("key2", "tata");
		master4.put("key3", "titi");
		master4.put("key4", "tutu");

		Map<Integer, String> master5 = new HashMap<Integer, String>();
		master5.put(new Integer(0), "toto");
		master5.put(new Integer(1), "tata");
		master5.put(new Integer(2), "titi");

		Map<String, Integer> master6 = new HashMap<String, Integer>();
		master6.put("toto", new Integer(0));
		master6.put("tata", new Integer(1));
		master6.put("titi", new Integer(2));

		Map<String, String> l1 = new HashMap<String, String>();
		Map<String, String> l2 = new TreeMap<String, String>();
		Map<String, String> l3 = new TreeMap<String, String>();
		Map<String, String> l4 = new TreeMap<String, String>();
		Map<String, String> l5 = new HashMap<String, String>();
		Map<String, String> l10 = new TreeMap<String, String>();
		Map<String, String> l11 = new HashMap<String, String>();
		Map<Integer, String> l12 = new TreeMap<Integer, String>();
		Map<String, Integer> l13 = new TreeMap<String, Integer>();
		l1.putAll(master);
		l2.putAll(master);
		l3.putAll(master2);
		l4.putAll(master3);
		l5.putAll(master4);
		l10.putAll(master_unordered);
		l11.putAll(master_unordered_2);
		l12.putAll(master5);
		l13.putAll(master6);

		assertTrue("same content", Tools.compareMap(l1, l2));
		assertTrue("same content 2", Tools.compareMap(l2, l1));
		assertFalse("not same content (object !=, same key)", Tools.compareMap(
				l1, l3));
		assertFalse("not same content (object !=, same key) 2", Tools
				.compareMap(l3, l1));
		assertFalse("not same content (same object, != key)", Tools.compareMap(
				l1, l4));
		assertFalse("not same content (same object, != key) 2", Tools
				.compareMap(l4, l1));
		assertFalse("not same content (not same size)", Tools
				.compareMap(l1, l5));
		assertFalse("not same content (not same size) 2", Tools.compareMap(l5,
				l1));

		Map<String, String> l6 = new TreeMap<String, String>();
		Map<String, String> l7 = new HashMap<String, String>();

		assertTrue("same content but empty", Tools.compareMap(l6, l7));
		assertTrue("same content but empty 2", Tools.compareMap(l7, l6));

		Map<String, String> l8 = null;
		Map<String, String> l9 = null;

		assertTrue("same content but null", Tools.compareMap(l8, l9));
		assertTrue("same content but null 2", Tools.compareMap(l9, l8));

		assertFalse("not same content (one null)", Tools.compareMap(l8, l1));
		assertFalse("not same content (one null) 2", Tools.compareMap(l1, l8));
		assertFalse("not same content (one empty)", Tools.compareMap(l6, l1));
		assertFalse("not same content (one empty) 2", Tools.compareMap(l1, l6));

		l5.remove("key4");
		assertTrue("same content (after change)", Tools.compareMap(l1, l5));

		assertFalse("not sameContent (not same type for key)", Tools
				.compareMap(l1, l12));
		assertFalse("not sameContent (not same type for key) 2", Tools
				.compareMap(l12, l1));
		assertFalse("not sameContent (not same type for object)", Tools
				.compareMap(l1, l13));
		assertFalse("not sameContent (not same type for object) 2", Tools
				.compareMap(l13, l1));

		/* Not good but ok with warning */
		assertTrue("same key in different order", Tools.compareMap(l10, l1));
		assertTrue("same key in different order 2", Tools.compareMap(l1, l10));
		assertTrue("same object in different order", Tools.compareMap(l11, l1));
		assertTrue("same object in different order 2", Tools
				.compareMap(l1, l11));
	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.common.Tools#getSecondPart(java.lang.String)}.
	 */
	@Test
	public final void testGetSecondPart() {
		String URI1 = "http://www.hitech-projects.com/euprojects/amigo/VerySimpleService.owl#ServiceAOp1Output";
		String URI2 = "http://www.hitech-projects.com/euprojects/amigo/VerySimpleService.owl";
		String URI3 = IO.UNKNOWN;

		assertEquals("get Second part ok ", "ServiceAOp1Output", Tools
				.getSecondPart(URI1));
		assertEquals("get Second part ko with # ", URI2, Tools
				.getSecondPart(URI2));
		assertEquals("get Second part ko with # 2", URI3, Tools
				.getSecondPart(URI3));
	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.common.Tools#getFirstPart(java.lang.String)}.
	 */
	@Test
	public final void testGetFirstPart() {
		String URI1 = "http://www.hitech-projects.com/euprojects/amigo/VerySimpleService.owl#ServiceAOp1Output";
		String URI2 = "http://www.hitech-projects.com/euprojects/amigo/VerySimpleService.owl";
		String URI3 = IO.UNKNOWN;

		assertEquals(
				"get Second part ok ",
				"http://www.hitech-projects.com/euprojects/amigo/VerySimpleService.owl",
				Tools.getFirstPart(URI1));
		assertEquals("get Second part ko with # ", URI2, Tools
				.getFirstPart(URI2));
		assertEquals("get Second part ko with # 2", URI3, Tools
				.getSecondPart(URI3));
	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.common.Tools#transformIntoEncodedURLString(java.lang.String)}.
	 */
	@Test
	public final void testTransformIntoEncodedURLString() {

		String s1 = "The string @foo-bar";
		String s2 = "The+string+%C3%BC%40foo-bar";
		assertEquals("test encoding", s2, Tools
				.transformIntoEncodedURLString(s1));

	}

}
