/**
 ##############################################################################
 # Copyright (C) 2006-2010 INRIA
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
 # version 2 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##############################################################################
 * 
 */
package fr.inria.icocoa.junittest.servicemodel;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

import fr.inria.icocoa.servicemodel.GroundingProperty;

/**
 * GroundingPropertyTest.java<br>
 * 
 * This class contains tests for the class
 * {@link fr.inria.icocoa.servicemodel.GroundingProperty}
 * 
 * @author <a href="mailto:sebastien.bianco@inria.fr">sebastien bianco</a> - <a
 *         href="http://www-rocq.inria.fr/arles">Arles Project - INRIA</a>
 * 
 * Creation Date : Apr 17, 2007 2:16:17 PM
 */
public class GroundingPropertyTest {

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.servicemodel.GroundingProperty#hashCode()}.
	 */
	@Test
	public final void testHashCode() {
		GroundingProperty in = new GroundingProperty();
		GroundingProperty in2 = new GroundingProperty();
		assertEquals("testHashCode ", true, in.hashCode() == in2.hashCode());

		GroundingProperty in4 = new GroundingProperty();
		GroundingProperty in3 = new GroundingProperty();
		in3.setConversationURI("coucou");
		in4.setConversationURI("coucou");
		assertEquals("testHashCode 2", true, in4.hashCode() == in3.hashCode());

		GroundingProperty in5 = new GroundingProperty();
		GroundingProperty in6 = new GroundingProperty();
		in5.setConversationURI("coucou");
		in6.setOperationName("coucou");
		assertEquals("testHashCode 3", false, in5.hashCode() == in6.hashCode());

		GroundingProperty in7 = new GroundingProperty();
		GroundingProperty in8 = new GroundingProperty();
		in7.setConversationURI("coucou");
		in8.setOperationName("coucou");
		assertEquals("testHashCode 4", false, in7.hashCode() == in8.hashCode());

		GroundingProperty in10 = new GroundingProperty();
		GroundingProperty in9 = new GroundingProperty();
		in10.setConversationURI(null);
		in9.setConversationURI(null);
		assertEquals("testHashCode 5", true, in10.hashCode() == in9.hashCode());
	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.servicemodel.GroundingProperty#equals(java.lang.Object)}.
	 */
	@Test
	public final void testEqualsObject() {
		GroundingProperty in = new GroundingProperty();
		GroundingProperty in2 = new GroundingProperty();
		GroundingProperty in3 = new GroundingProperty();
		GroundingProperty in4 = new GroundingProperty();
		GroundingProperty in5 = new GroundingProperty();
		in3.setConversationURI("toto");
		in4.setOperationName("toto");
		in5.setOperationPortType("toto");

		// equals
		assertEquals("testEqualsObject : same object", true, in.equals(in));
		assertEquals("testEqualsObject : same semantic", true, in.equals(in2));
		assertEquals("testEqualsObject : same reference", true, in == in);

		// not equals
		assertEquals("testEqualsObject : not same reference", true, in != in2);
		assertEquals("testEqualsObject : not same semantic 1", false, in
				.equals(in3));
		assertEquals("testEqualsObject : not same semantic 2", false, in
				.equals(in4));
		assertEquals("testEqualsObject : not same semantic 3", false, in
				.equals(in5));
		assertEquals("testEqualsObject : not same semantic 4", false, in3
				.equals(in4));
		assertEquals("testEqualsObject : not same semantic 5", false, in3
				.equals(in5));
		assertEquals("testEqualsObject : not same semantic 6", false, in4
				.equals(in5));
	}

}
