/**
 ##############################################################################
 # Copyright (C) 2006-2010 INRIA
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
 # version 2 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##############################################################################
 * 
 */
package fr.inria.icocoa.junittest.servicemodel;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;
import junit.framework.JUnit4TestAdapter;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

import fr.inria.icocoa.servicemodel.IO;
import fr.inria.icocoa.servicemodel.Input;

/**
 * InputTest.java<br>
 * 
 * This class contains tests for the class
 * {@link fr.inria.icocoa.servicemodel.Input}
 * 
 * @author <a href="mailto:sebastien.bianco@inria.fr">sebastien bianco</a> - <a
 *         href="http://www-rocq.inria.fr/arles">Arles Project - INRIA</a>
 * 
 * Creation Date : Apr 17, 2007 10:58:32 AM
 */
public class InputTest {

	/**
	 * @throws java.lang.Exception
	 */
	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
	}

	/**
	 * @throws java.lang.Exception
	 */
	@AfterClass
	public static void tearDownAfterClass() throws Exception {
	}

	/**
	 * @throws java.lang.Exception
	 */
	@Before
	public void setUp() throws Exception {
	}

	/**
	 * @throws java.lang.Exception
	 */
	@After
	public void tearDown() throws Exception {
	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.servicemodel.Input#equals(java.lang.Object)}.
	 */
	@Test
	public final void testEqualsObject() {
		Input in = new Input("toto", "titi", "tata");
		Input in2 = new Input("toto", "titi", "tata");
		Input in3 = new Input("toto2", "titi", "tata");
		Input in4 = new Input("toto", "titi2", "tata");
		Input in5 = new Input("toto", "titi", "tata2");

		// equals
		assertEquals("testEqualsObject : same object", true, in.equals(in));
		assertEquals("testEqualsObject : same semantic", true, in.equals(in2));
		assertEquals("testEqualsObject : same reference", true, in == in);

		// not equals
		assertEquals("testEqualsObject : not same reference", true, in != in2);
		assertEquals("testEqualsObject : not same semantic 1", false, in
				.equals(in3));
		assertEquals("testEqualsObject : not same semantic 2", false, in
				.equals(in4));
		assertEquals("testEqualsObject : not same semantic 3", false, in
				.equals(in5));

		in2.setProvided(true);
		assertEquals("testEqualsObject : not same semantic 4", false, in
				.equals(in2));
	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.servicemodel.Input#Input(java.lang.String)}.
	 */
	@Test
	public final void testInputString() {
		Input in = new Input("toto");
		Input in2 = new Input("toto", IO.UNKNOWN, IO.UNKNOWN);
		assertEquals("testInputString : same semantic", true, in.equals(in2));
	}

	/**
	 * Test method for {@link fr.inria.icocoa.servicemodel.IO#hashCode()}.
	 */
	@Test
	public final void testHashCode() {
		Input in = new Input("toto", "titi", "tata");
		Input in2 = new Input("toto", "titi", "tata");
		assertEquals("testHashCode : same hashCode", true, in.hashCode() == in2
				.hashCode());

		Input in3 = new Input("toto", "tata", "titi");
		Input in4 = new Input("toto", "titi", "tata");
		assertEquals("testHashCode : different hashCode", false,
				in3.hashCode() == in4.hashCode());

		Input in5 = new Input("toto", "titi", null);
		Input in6 = new Input("toto", "titi", null);
		assertEquals("testHashCode : same hashCode 2", true,
				in5.hashCode() == in6.hashCode());

		in2.setProvided(true);
		assertEquals("testHashCode : not same hashCode", false,
				in.hashCode() == in2.hashCode());
	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.servicemodel.IO#setType(java.lang.String)}.
	 */
	@Test
	public final void testSetType() {
		Input in = new Input("toto", "titi", "tata");
		in.setType("blabla#bloblo");
		assertEquals("test localName", "tata", in.getLocalName());
		assertEquals("test Name", "bloblo", in.getTypeName());
		assertEquals("test Ontology", "blabla", in.getOntology());
		assertEquals("test getType", "blabla#bloblo", in.getType());
	}

	/**
	 * Test method for {@link fr.inria.icocoa.servicemodel.IO#getType()}.
	 */
	@Test
	public final void testGetType() {
		Input in = new Input("toto", "titi", "tata");
		assertEquals("test getType", "titi#toto", in.getType());
	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.servicemodel.Input#containsMoreInformation(fr.inria.icocoa.servicemodel.Input)}.
	 */
	@Test
	public final void testContainsMoreInformation() {
		assertEquals("test inputs 0", 0, new Input("a", "a#a")
				.containsMoreInformation(new Input("a", "a#a")));

		Input a = new Input("a", "a#a");
		a.setLocalName(IO.UNKNOWN);
		a.setType(IO.UNKNOWN + "#" + IO.UNKNOWN);
		assertTrue("test inputs <0", a.containsMoreInformation(new Input("a",
				"a#a")) < 0);
		assertTrue("test inputs >0", new Input("a", "a#a")
				.containsMoreInformation(a) > 0);
	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.servicemodel.Input#transfertInformation(fr.inria.icocoa.servicemodel.Input)}.
	 */
	@Test
	public final void testTransfertInformation() {

		Input a = new Input("a", "a#a");
		Input b = new Input("mylocalName", "myOntoilogy#myConceptName");
		b.setProvided(true);
		b.setGroundingValue("titi");

		assertFalse("inputs not equals", a.equals(b));

		a.transfertInformation(b);
		assertTrue("inputs equals", a.equals(b));
	}

	/**
	 * Test method for
	 * {@link fr.inria.icocoa.servicemodel.IO#countNullOrUnknowField()}.
	 */
	@Test
	public final void testCountNullOrUnknowField() {
		assertEquals("test input 1", 1, new Input("a", "a#a")
				.countNullOrUnknowField());

		Input a = new Input("a", "a#a");
		a.setLocalName(IO.UNKNOWN);
		a.setType(IO.UNKNOWN + "#" + IO.UNKNOWN);
		assertEquals("test input 4", 4, a.countNullOrUnknowField());

		Input b = new Input("a", "a#a");
		b.setGroundingValue("toto");
		assertEquals("test input 0", 0, b.countNullOrUnknowField());

		Input c = new Input("a", "a#a");
		c.setLocalName(IO.UNKNOWN);
		assertEquals("test input 2", 2, c.countNullOrUnknowField());

	}

	/**
	 * Generate the suite of Test of Input class
	 * 
	 * @return a Test object
	 */
	public static junit.framework.Test suite() {
		return new JUnit4TestAdapter(InputTest.class);
	}

}
